@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2013 Red Hat, Inc.
+ * Copyright (C) 2011, 2013, 2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: David Zeuthen <davidz@redhat.com>
  *          Debarshi Ray <debarshir@gnome.org>
@@ -50,6 +48,8 @@ GoaMailAuth *goa_smtp_auth_new       (GoaProvider       *provider,
                                       const gchar       *domain,
                                       const gchar       *user_name,
                                       const gchar       *password);
+gboolean     goa_smtp_auth_is_login  (GoaSmtpAuth       *auth);
+gboolean     goa_smtp_auth_is_plain  (GoaSmtpAuth       *auth);
 
 G_END_DECLS
 
