@@ -46,9 +46,6 @@ struct _GoaIdentityServicePrivate
 
   GoaIdentityManager       *identity_manager;
 
-  guint                     realmd_watch;
-  GCancellable             *cancellable;
-
   GHashTable               *watched_client_connections;
   GHashTable               *key_holders;
   GHashTable               *pending_temporary_account_results;
@@ -1599,7 +1596,7 @@ on_identities_listed (GoaIdentityManager *manager,
           g_warning ("Could not list identities: %s", error->message);
           g_error_free (error);
         }
-      return;
+      goto out;
     }
 
   for (node = identities; node != NULL; node = node->next)
@@ -1619,6 +1616,9 @@ on_identities_listed (GoaIdentityManager *manager,
       else
         g_object_unref (object);
     }
+
+ out:
+  g_object_unref (self);
 }
 
 static void
@@ -1681,7 +1681,7 @@ on_got_client (GoaClient          *client,
   if (self->priv->client == NULL)
     {
       g_warning ("Could not create client: %s", error->message);
-      return;
+      goto out;
     }
 
   self->priv->accounts_manager = goa_client_get_manager (client);
@@ -1691,16 +1691,19 @@ on_got_client (GoaClient          *client,
   if (self->priv->identity_manager == NULL)
     {
       g_warning ("Could not create identity manager: %s", error->message);
-      return;
+      goto out;
     }
 
   goa_identity_manager_list_identities (self->priv->identity_manager,
                                         NULL,
                                         (GAsyncReadyCallback)
                                         on_identities_listed,
-                                        self);
+                                        g_object_ref (self));
 
   ensure_credentials_for_accounts (self);
+
+ out:
+  g_object_unref (self);
 }
 
 static void
@@ -1720,7 +1723,7 @@ on_session_bus_acquired (GDBusConnection    *connection,
     goa_client_new (NULL,
                     (GAsyncReadyCallback)
                     on_got_client,
-                    self);
+                    g_object_ref (self));
   }
 }
 
@@ -1752,8 +1755,6 @@ goa_identity_service_activate (GoaIdentityService   *self,
 
   g_debug ("GoaIdentityService: Activating identity service");
 
-  self->priv->cancellable = g_cancellable_new ();
-
   self->priv->object_manager_server =
     g_dbus_object_manager_server_new ("/org/gnome/Identity");
 
@@ -1783,9 +1784,6 @@ goa_identity_service_deactivate (GoaIdentityService *self)
 {
   g_debug ("GoaIdentityService: Deactivating identity service");
 
-  if (self->priv->realmd_watch == 0)
-    g_bus_unwatch_name (self->priv->realmd_watch);
-
   if (self->priv->identity_manager != NULL)
     {
       g_signal_handlers_disconnect_by_func (self, on_identity_needs_renewal, self);
@@ -1797,7 +1795,6 @@ goa_identity_service_deactivate (GoaIdentityService *self)
   g_clear_object (&self->priv->object_manager_server);
   g_clear_object (&self->priv->connection);
   g_clear_object (&self->priv->client);
-  g_clear_object (&self->priv->cancellable);
 }
 
 static void
